﻿Public Class Form1
    ' Define the number of questions and max number for the answers
    Private questions As Integer = 7
    Private currentQuestionIndex As Integer = 0
    Private correctAnswers As Integer = 0
    Private random As New Random()
    Private hintNumber As Integer

    Private Sub Form1_Load(sender As Object, e As EventArgs) Handles MyBase.Load
        Randomize()
        LoadQuestion()
        btnNext.Enabled = False ' Disable the Next button initially
    End Sub

    Private Sub LoadQuestion()
        Dim n As Integer = 10 + currentQuestionIndex * 2
        Dim correctAnswer As String = String.Join(" ", Enumerable.Range(1, n))
        Dim incorrectAnswer As String = GenerateIncorrectAnswer(n)

        lblQuestion.Text = $"Which of the following sets of numbers counts correctly from 1 to {n}?"

        Dim answers As String() = {correctAnswer, incorrectAnswer}
        answers = answers.OrderBy(Function(x) random.Next()).ToArray()

        rbOption1.Text = answers(0)
        rbOption2.Text = answers(1)

        lblFeedback.Text = String.Empty
        lblHint.Text = String.Empty  ' Clear any existing hints

        rbOption1.Checked = False
        rbOption2.Checked = False

        btnNext.Enabled = False ' Disable the Next button until an answer is selected
    End Sub

    Private Function GenerateIncorrectAnswer(n As Integer) As String
        Dim numbersSet As New List(Of Integer)
        Dim numbersSet2 As New List(Of Integer)

        For i = 1 To n
            numbersSet2.Add(i)
        Next

        Do
            numbersSet.Clear()
            While numbersSet.Count < n  ' Ensure that we do not include all numbers to make it incorrect
                Dim pos1 As Integer
                If Rnd() < 0.001 Then
                    Do
                        pos1 = random.Next(1, n + 1)
                    Loop Until Not numbersSet.Contains(pos1)
                    numbersSet.Add(pos1)
                Else
                    pos1 = numbersSet.Count + 1
                    If numbersSet.Contains(pos1) Then
                        Dim pos2 As Integer = 0
                        Do
                            pos2 = pos2 + 1
                            If Not numbersSet.Contains(pos2) Then
                                pos1 = pos2
                                Exit Do
                            End If
                        Loop
                    End If
                    numbersSet.Add(pos1)
                End If
            End While
        Loop Until Not CompareLists(numbersSet, numbersSet2)

        Return String.Join(" ", numbersSet)
    End Function

    Function CompareLists(list1 As List(Of Integer), list2 As List(Of Integer)) As Boolean
        If list1.Count <> list2.Count Then
            Return False
        End If

        For i As Integer = 0 To list1.Count - 1
            If list1(i) <> list2(i) And Math.Abs(list1(i) - list2(i)) < 3 Then
                hintNumber = list1(i)
                Return False
            End If
        Next

        Return True
    End Function

    Private Sub btnSubmit_Click(sender As Object, e As EventArgs) Handles btnSubmit.Click
        Dim n As Integer = 10 + currentQuestionIndex * 2
        Dim correctAnswer As String = String.Join(" ", Enumerable.Range(1, n))

        If rbOption1.Checked Then
            If rbOption1.Text.Trim() = correctAnswer Then
                lblFeedback.Text = "Correct! That is one way we count."
                correctAnswers += 1
            Else
                lblFeedback.Text = "Incorrect! This order misses some numbers."
                ProvideHint(correctAnswer)
            End If
        ElseIf rbOption2.Checked Then
            If rbOption2.Text.Trim() = correctAnswer Then
                lblFeedback.Text = "Correct! That is one way we count."
                correctAnswers += 1
            Else
                lblFeedback.Text = "Incorrect! This order misses some numbers."
                ProvideHint(correctAnswer)
            End If
        Else
            lblFeedback.Text = "Please select an option."
            Return
        End If

        btnNext.Enabled = True
        btnSubmit.Enabled = False ' Disable the Submit button after answering
    End Sub

    Private Sub ProvideHint(correctAnswer As String)
        ' Construct a hint message
        Dim hintMessage As String
        hintMessage = $"Hint: "

        hintMessage &= $"Look at the number: {hintNumber}."

        lblHint.Text = hintMessage
    End Sub

    Private Sub btnNext_Click(sender As Object, e As EventArgs) Handles btnNext.Click
        currentQuestionIndex += 1
        If currentQuestionIndex < questions Then
            LoadQuestion()
            btnSubmit.Enabled = True
        Else
            DisplayFinalScore()
            btnNext.Enabled = False
            btnSubmit.Enabled = False
        End If
    End Sub

    Private Sub DisplayFinalScore()
        Dim scorePercentage As Integer = CInt((correctAnswers / questions) * 100)
        lblHint.Text = ""
        lblFeedback.Text = $"Quiz completed! Your score: {correctAnswers} out of {questions} ({scorePercentage}%)."
    End Sub

    Private Sub Form1_Shown(sender As Object, e As EventArgs) Handles Me.Shown
        rbOption1.Checked = False
    End Sub
End Class
